# User Guide

Detailed guides for using NeuroBrix in production.

## Topics

- **[Serving Models](serving.md)** — Persistent daemon for fast repeated inference
- **[Single-Shot Inference](inference.md)** — One-off model execution
- **[Hardware Profiles](hardware.md)** — Configure for your GPU setup
